@@ -1,15 +1,15 @@
 #' User-defined variables passed to Stan
-#' 
-#' Prepare user-defined variables to be passed to one of Stan's 
-#' program blocks. This is primarily useful for defining more complex 
-#' priors, for refitting models without recompilation despite 
+#'
+#' Prepare user-defined variables to be passed to one of Stan's
+#' program blocks. This is primarily useful for defining more complex
+#' priors, for refitting models without recompilation despite
 #' changing priors, or for defining custom Stan functions.
-#' 
+#'
 #' @aliases stanvars
-#'  
+#'
 #' @param x An \R object containing data to be passed to Stan.
 #'   Only required if \code{block = 'data'} and ignored otherwise.
-#' @param name Optional character string providing the desired variable 
+#' @param name Optional character string providing the desired variable
 #'  name of the object in \code{x}. If \code{NULL} (the default)
 #'  the variable name is directly inferred from \code{x}.
 #' @param scode Line of Stan code to define the variable
@@ -28,43 +28,43 @@
 #'  of \code{partial_log_lik} functions. This ensures that the variables
 #'  specified in \code{scode} can be used in the likelihood even when
 #'  within-chain parallelization is activated via \code{\link{threading}}.
-#'  
+#'
 #' @return An object of class \code{stanvars}.
-#' 
-#' @examples 
+#'
+#' @examples
 #' bprior <- prior(normal(mean_intercept, 10), class = "Intercept")
 #' stanvars <- stanvar(5, name = "mean_intercept")
-#' make_stancode(count ~ Trt, epilepsy, prior = bprior, 
+#' make_stancode(count ~ Trt, epilepsy, prior = bprior,
 #'               stanvars = stanvars)
-#'               
+#'
 #' # define a multi-normal prior with known covariance matrix
 #' bprior <- prior(multi_normal(M, V), class = "b")
 #' stanvars <- stanvar(rep(0, 2), "M", scode = "  vector[K] M;") +
-#'   stanvar(diag(2), "V", scode = "  matrix[K, K] V;") 
+#'   stanvar(diag(2), "V", scode = "  matrix[K, K] V;")
 #' make_stancode(count ~ Trt + zBase, epilepsy,
 #'               prior = bprior, stanvars = stanvars)
-#'               
+#'
 #' # define a hierachical prior on the regression coefficients
 #' bprior <- set_prior("normal(0, tau)", class = "b") +
 #'   set_prior("target += normal_lpdf(tau | 0, 10)", check = FALSE)
-#' stanvars <- stanvar(scode = "real<lower=0> tau;", 
+#' stanvars <- stanvar(scode = "real<lower=0> tau;",
 #'                     block = "parameters")
 #' make_stancode(count ~ Trt + zBase, epilepsy,
 #'               prior = bprior, stanvars = stanvars)
-#'               
+#'
 #' # ensure that 'tau' is passed to the likelihood of a threaded model
 #' # not necessary for this example but may be necessary in other cases
-#' stanvars <- stanvar(scode = "real<lower=0> tau;", 
+#' stanvars <- stanvar(scode = "real<lower=0> tau;",
 #'                     block = "parameters", pll_args = "real tau")
 #' make_stancode(count ~ Trt + zBase, epilepsy,
 #'               stanvars = stanvars, threads = threading(2))
-#' 
+#'
 #' @export
 stanvar <- function(x = NULL, name = NULL, scode = NULL,
                     block = "data", position = "start",
                     pll_args = NULL) {
   vblocks <- c(
-    "data", "tdata", "parameters", "tparameters", 
+    "data", "tdata", "parameters", "tparameters",
     "model", "genquant", "functions", "likelihood"
   )
   block <- match.arg(block, vblocks)
@@ -79,7 +79,7 @@ stanvar <- function(x = NULL, name = NULL, scode = NULL,
     }
     name <- as_one_character(name)
     if (!is_equal(name, make.names(name)) || grepl("\\.", name)) {
-      stop2("'", limit_chars(name, 30), "' is not ", 
+      stop2("'", limit_chars(name, 30), "' is not ",
             "a valid variable name in Stan.")
     }
     if (is.null(scode)) {
@@ -114,23 +114,24 @@ stanvar <- function(x = NULL, name = NULL, scode = NULL,
     }
     if (is.null(pll_args)) {
       # infer pll_args from x
+      pll_type <- str_if(block %in% c("data", "tdata"), "data ")
       if (is.integer(x)) {
         if (length(x) == 1L) {
-          pll_type <- "int"
+          pll_type <- paste0(pll_type, "int")
         } else {
-          pll_type <- "int[]"
+          pll_type <- paste0(pll_type, "int[]")
         }
       } else if (is.vector(x)) {
         if (length(x) == 1L) {
-          pll_type <- "real"
+          pll_type <- paste0(pll_type, "real")
         } else {
-          pll_type <- "vector"
+          pll_type <- paste0(pll_type, "vector")
         }
       } else if (is.array(x)) {
         if (length(dim(x)) == 1L) {
-          pll_type <- "vector"
+          pll_type <- paste0(pll_type, "vector")
         } else if (is.matrix(x)) {
-          pll_type <- "matrix"
+          pll_type <- paste0(pll_type, "matrix")
         }
       }
       if (!is.null(pll_type)) {
@@ -152,14 +153,14 @@ stanvar <- function(x = NULL, name = NULL, scode = NULL,
     scode <- as.character(scode)
     pll_args <- as.character(pll_args)
   }
-  if (position == "end" && block %in% c("functions", "data", "model")) {
+  if (position == "end" && block %in% c("functions", "data")) {
     stop2("Position '", position, "' is not sensible for block '", block, "'.")
   }
   out <- nlist(name, sdata = x, scode, block, position, pll_args)
   structure(setNames(list(out), name), class = "stanvars")
 }
 
-# take a subset of a stanvars object 
+# take a subset of a stanvars object
 # @param x a stanvars object
 # @param ... conditions defining the desired subset
 subset_stanvars <- function(x, ...) {
@@ -207,7 +208,7 @@ validate_stanvars <- function(x, stan_funs = NULL) {
     stop2("Argument 'stanvars' is invalid. See ?stanvar for help.")
   }
   if (length(stan_funs) > 0) {
-    warning2("Argument 'stan_funs' is deprecated. Please use argument ", 
+    warning2("Argument 'stan_funs' is deprecated. Please use argument ",
              "'stanvars' instead. See ?stanvar for more help.")
     stan_funs <- as_one_character(stan_funs)
     x <- x + stanvar(scode = stan_funs, block = "functions")
