@@ -9,8 +9,8 @@ opts_chunk$set(
   message = FALSE,
   warning = FALSE,
   eval = if (isTRUE(exists("params"))) params$EVAL else FALSE,
-  dev = "png",
-  dpi = 150,
+  dev = "jpeg",
+  dpi = 100,
   fig.asp = 0.8,
   fig.width = 5,
   out.width = "60%",
@@ -24,10 +24,11 @@ data("BTdata", package = "MCMCglmm")
 head(BTdata)
 
 ## ----fit1, message=FALSE, warning=FALSE, results='hide'---------------------------------
-fit1 <- brm(
-  mvbind(tarsus, back) ~ sex + hatchdate + (1|p|fosternest) + (1|q|dam),
-  data = BTdata, chains = 2, cores = 2
-)
+bform1 <- 
+  bf(mvbind(tarsus, back) ~ sex + hatchdate + (1|p|fosternest) + (1|q|dam)) +
+  set_rescor(TRUE)
+
+fit1 <- brm(bform1, data = BTdata, chains = 2, cores = 2)
 
 ## ----summary1, warning=FALSE------------------------------------------------------------
 fit1 <- add_criterion(fit1, "loo")
@@ -43,7 +44,8 @@ bayes_R2(fit1)
 ## ----fit2, message=FALSE, warning=FALSE, results='hide'---------------------------------
 bf_tarsus <- bf(tarsus ~ sex + (1|p|fosternest) + (1|q|dam))
 bf_back <- bf(back ~ hatchdate + (1|p|fosternest) + (1|q|dam))
-fit2 <- brm(bf_tarsus + bf_back, data = BTdata, chains = 2, cores = 2)
+fit2 <- brm(bf_tarsus + bf_back + set_rescor(TRUE), 
+            data = BTdata, chains = 2, cores = 2)
 
 ## ----summary2, warning=FALSE------------------------------------------------------------
 fit2 <- add_criterion(fit2, "loo")
@@ -59,7 +61,7 @@ bf_back <- bf(back ~ s(hatchdate) + (1|p|fosternest) + (1|q|dam)) +
   gaussian()
 
 fit3 <- brm(
-  bf_tarsus + bf_back + set_rescor(FALSE), 
+  bf_tarsus + bf_back + set_rescor(FALSE),
   data = BTdata, chains = 2, cores = 2,
   control = list(adapt_delta = 0.95)
 )
